@@ -19,6 +19,7 @@ namespace   // the anonymous namespace can be used here
         Arg::LongOption("tmp", 't'),
         Arg::LongOption("umask", Arg::Required),
         Arg::LongOption("version", 'v'),
+        Arg::LongOption("x-headers", 'x'),
     };
 
     Arg::LongOption const *const longEnd =
@@ -29,10 +30,8 @@ namespace   // the anonymous namespace can be used here
 int main(int argc, char **argv)
 try
 {
-    Arg::initialize("dhL:l:m:n:r:t:v", longOptions, longEnd, 
-                    argc, argv).versionHelp(usage, version, 0);
-
-    Remailer remailer;
+    Remailer remailer{ preamble("dhL:l:m:n:r:t:vx", 
+                                longOptions, longEnd, argc, argv) };
 
     try
     {
@@ -64,21 +63,15 @@ try
 
         // ALL exceptions return 0 to prevent unexpected mailer errors in 
         // sendmail's logs.
-
-        return 0;
     }
 }
 catch(exception const &err)     // handle exceptions
 {
     cerr << "[Fatal] " << err.what() << '\n';
-    return 0;
-}
-catch(int x)
-{
-    return 0;
 }
+catch(int)
+{}
 catch (...)
 {
     cerr << "unexpected exception caught in main()\n";
-    return 0;
 }
